==> kubernetes-model-extensions-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/extensions/NetworkPolicyPortFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NetworkPolicyPortFluent<A extends io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.Integer getEndPort();
  public A withEndPort(java.lang.Integer endPort);
  public java.lang.Boolean hasEndPort();
  
  /**
   * This method has been deprecated, please use method buildPort instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getPort();
  public io.fabric8.kubernetes.api.model.IntOrString buildPort();
  public A withPort(io.fabric8.kubernetes.api.model.IntOrString port);
  public java.lang.Boolean hasPort();
  public A withNewPort(java.lang.Integer intVal);
  public A withNewPort(java.lang.String strVal);
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> withNewPort();
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> withNewPortLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> editPort();
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> editOrNewPort();
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> editOrNewPortLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public java.lang.String getProtocol();
  public A withProtocol(java.lang.String protocol);
  public java.lang.Boolean hasProtocol();
  
  /**
   * Method is deprecated. use withProtocol instead.
   */
  @java.lang.Deprecated
  public A withNewProtocol(java.lang.String arg0);
  public interface PortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.IntOrStringFluent<io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<N>>{
    public N and();
    public N endPort();
    
  }
  
}

==> kubernetes-model-extensions-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/extensions/NetworkPolicyPortFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NetworkPolicyPortFluent<A extends io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.Integer getEndPort();
  public A withEndPort(java.lang.Integer endPort);
  public java.lang.Boolean hasEndPort();
  
  /**
   * This method has been deprecated, please use method buildPort instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getPort();
  public io.fabric8.kubernetes.api.model.IntOrString buildPort();
  public A withPort(io.fabric8.kubernetes.api.model.IntOrString port);
  public java.lang.Boolean hasPort();
  public A withNewPort(java.lang.Integer intVal);
  public A withNewPort(java.lang.String strVal);
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> withNewPort();
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> withNewPortLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> editPort();
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> editOrNewPort();
  public io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<A> editOrNewPortLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public java.lang.String getProtocol();
  public A withProtocol(java.lang.String protocol);
  public java.lang.Boolean hasProtocol();
  
  /**
   * Method is deprecated. use withProtocol instead.
   */
  @java.lang.Deprecated
  public A withNewProtocol(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface PortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.IntOrStringFluent<io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPortFluent.PortNested<N>>{
    public N and();
    public N endPort();
    
  }
  
}
